[−][src]Struct allo_isolate::Isolate
Simple wrapper around the Dart Isolate Port, nothing else.
Implementations
impl Isolate[src]
pub const fn new(port: i64) -> Self[src]
Create a new Isolate with a port obtained from Dart VM side.
Example
this a non realistic example lol :D
let isolate = Isolate::new(42);
pub fn post(&self, msg: impl IntoDart) -> bool[src]
Post an object to the Isolate over the port
Object must implement IntoDart.
returns true if the message posted successfully, otherwise false
Safety
This assumes that you called store_dart_post_cobject and we have
access to the Dart_PostCObject function pointer also, we do check
if it is not null.
Example
let isolate = Isolate::new(42); isolate.post("Hello Dart !");